( cd opt/kde/share/doc/HTML/en/ktechlab ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/ktechlab ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/lib ; rm -rf libtechmath.0 )
( cd opt/kde/lib ; ln -sf libtechmath.0.0.0 libtechmath.0 )
( cd opt/kde/lib ; rm -rf libtechmath )
( cd opt/kde/lib ; ln -sf libtechmath.0.0.0 libtechmath )
