<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
<kpartgui name="KTechlabCircuit" version="4">
	<MenuBar>
		<Menu name="tools">
			<text>&amp;Tools</text>
			<Separator/>
			<Menu name="routing_mode_menu">
				<text>Routing Mode</text>
				<Action name="routing_mode_auto"/>
				<Action name="routing_mode_manual"/>
			</Menu>
			<Action name="edit_mode_manual_route"/>
			<Action name="edit_rotate_cw"/>
			<Action name="edit_rotate_ccw"/>
		</Menu>
	</MenuBar>
	
	<ToolBar name="toolsToolBar">
		<Separator/>
		<Action name="routing_mode"/>
		<Action name="edit_draw"/>
		<Action name="edit_rotate_ccw"/>
		<Action name="edit_rotate_cw"/>
	</ToolBar>
	
	<ToolBar name="itemEditorTB" noMerge="1">
		<text>Item Editor</text>
<!-- 		<Action name="null_action"/> -->
	</ToolBar>
</kpartgui>

