<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
<kpartgui name="KTechlab" version="7">
	<MenuBar>
		<Menu name="file">
			<text>&amp;File</text>
			<DefineGroup name="save_merge"/>
		</Menu>
		
		<Menu name="view">
			<text>&amp;View</text>
			<Action name="view_split_leftright"/>
			<Action name="view_split_topbottom"/>
			<Action name="view_close_activeview"/>
			<Separator/>
		</Menu>
		
		<Menu name="project">
			<text>&amp;Project</text>
			<Action name="project_new"/>
			<Action name="project_open"/>
			<Action name="project_open_recent"/>
			<Separator/>
			<Action name="project_options"/>
			<Action name="project_create_subproject"/>
<!-- 			<Action name="project_export_makefile"/> -->
			<Separator/>
			<Action name="project_add_current_file"/>
			<Action name="project_add_existing_file"/>
			<Separator/>
			<Action name="project_close"/>
		</Menu>
		
		<Menu name="tools">
			<text>&amp;Tools</text>
			<Action name="simulation_run"/>
		</Menu>
		
		<DefineGroup name="bookmarks_merge"/>
		<DefineGroup name="debug_merge"/>
	</MenuBar>
	
	<!-- When there is no project open -->
	<Menu name="project_none_popup">
		<Action name="project_new"/>
		<Action name="project_open"/>
		<Action name="project_open_recent"/>
	</Menu>
		
	
	<Menu name="project_file_popup">
		<Action name="project_item_linker_options"/>
		<Action name="project_item_processing_options"/>
		<Separator/>
		<Action name="project_item_build"/>
		<Action name="project_item_upload"/>
		<Separator/>
		<Action name="project_remove_selected"/>
		<Separator/>
			<Action name="project_close"/>
	</Menu>
	
	<Menu name="project_file_other_popup">
		<Action name="project_remove_selected"/>
		<Separator/>
		<Action name="project_close"/>
	</Menu>
	
	<Menu name="project_program_popup">
		<Action name="project_item_linker_options"/>
		<Action name="project_item_processing_options"/>
		<Separator/>
		<Action name="project_item_build"/>
		<Action name="project_item_upload"/>
		<Separator/>
		<Action name="subproject_add_current_file"/>
		<Action name="subproject_add_existing_file"/>
		<Separator/>
		<Action name="project_remove_selected"/>
		<Separator/>
		<Action name="project_close"/>
	</Menu>
	
	<Menu name="project_library_popup">
		<Action name="project_item_linker_options"/>
		<Action name="project_item_processing_options"/>
		<Separator/>
		<Action name="project_item_build"/>
		<Separator/>
		<Action name="subproject_add_current_file"/>
		<Action name="subproject_add_existing_file"/>
		<Separator/>
		<Action name="project_remove_selected"/>
		<Separator/>
		<Action name="project_close"/>
	</Menu>
	
	<Menu name="project_blank_popup">
		<Action name="project_create_subproject"/>
		<Separator/>
		<Action name="project_add_current_file"/>
		<Action name="project_add_existing_file"/>
		<Separator/>
		<Action name="project_close"/>
	</Menu>
	
	<Menu name="item_popup">
		<Action name="edit_undo"/>
		<Action name="edit_redo"/>
		<Separator/>
		<Action name="edit_delete"/>
		<Action name="edit_cut"/>
		<Action name="edit_copy"/>
		<Action name="edit_paste"/>
		<Separator/>
		<ActionList name="alignment_actionlist"/>
		<ActionList name="orientation_actionlist"/>
		<ActionList name="component_actionlist"/>
	</Menu>
	
	<Menu name="ktexteditor_popup">
		<Action name="edit_undo" group="popup_operations" />
		<Action name="edit_redo" group="popup_operations" />
		<Separator group="popup_operations" />
		<Action name="edit_cut" group="popup_operations" />
		<Action name="edit_copy" group="popup_operations" />
		<Action name="edit_paste" group="popup_operations" />
		<Separator group="popup_operations" />
		<Action name="edit_select_all" group="popup_operations" />
		<Action name="edit_deselect" group="popup_operations" />
		<Separator group="popup_operations" />
		<Action name="bookmarks" group="popup_operations" />
		<Separator group="popup_operations" />
	</Menu>
</kpartgui>

